from .log import log
import requests
from .config import *

def get_changes(repository, pr):
    response = requests.get(f'{api}/repos/{repository}/pulls/{pr}/files')
    log.debug(f'Attempted to fetch changes from {response.url}')
    if response.status_code != 200:
        log.error('Failed to query files')
        return []
    data = response.json()
    files = []
    for file in data:
        if 'filename' in file:
            files.append(file['filename'])
    log.debug(f'Returning files: {files}')
    return files

def comment(repository, index, body):
    response = requests.post(f'{api}/repos/{repository}/issues/{index}/comments', headers={'Authorization': f'token {config["token"]}'}, data={'body': body})
    log.debug(f'Attempted to comment via {response.url}, received HTTP {response.status_code}')
    if response.status_code != 201:
        log.error('Failed to post comment')
    return response.json()

def reviewed(repository, index):
    response = requests.get(f'{api}/repos/{repository}/pulls/{index}/reviews')
    data = response.json()
    for review in data:
        if review.get('user', {}).get('login') == 'butler':
            if review.get('state') is True:
                return True
    return False

def review(repository, index):
    response = requests.post(f'{api}/repos/{repository}/pulls/{index}/reviews', headers={'Authorization': f'token {config["token"]}'}, data={'body': 'Sufficient CODEOWNER approvals.', 'event': 'APPROVED'})
    log.debug(f'Attempted to review via {response.url}, received HTTP {response.status_code}')
    data = response.json()
    log.debug(f'Received response: {data}')
    if response.status_code != 200:
        log.error('Failed to submit review')
    return data

def merge(repository, index):
    response = requests.post(f'{api}/repos/{repository}/pulls/{index}/merge', headers={'Authorization': f'token {config["token"]}'}, data={'do': 'merge'})
    log.debug(f'Attempted to merge via {response.url}, received HTTP {response.status_code}')
    if response.headers.get('content-type') == 'application/json':
        data = response.json()
        log.debug(f'Received response: {data}')
        if response.status_code == 405 and data['message'] == 'not allowed to merge [reason: Does not have enough approvals]':
            log.warning('Failed to merge, insufficient global approvals')
        return data
    elif response.status_code != 200:
        log.error('Failed to merge')
